=======
Credits
=======

Development Lead
----------------

* Agate Blue

Contributors
------------

* Ryan Anguiano, via `prefs-n-perms package <https://github.com/revpoint/prefs-n-perms>`_
* [@willseward](https://github.com/willseward)
* [@haroon-sheikh](https://github.com/haroon-sheikh)
* [@yurtaev](https://github.com/yurtaev)
* [@pomerama](https://github.com/pomerama)
* [@philipbelesky](https://github.com/philipbelesky)
* [@what-digital](https://github.com/what-digital)
* [@czlee](https://github.com/czlee)
* [@ricard33](https://github.com/ricard33)
* [@JetUni](https://github.com/JetUni)
* [@pip182](https://github.com/pip182)
* [@JanMalte](https://github.com/JanMalte)
* [@macolo](https://github.com/macolo)
* [@fabrixxm](https://github.com/fabrixxm)
* [@swalladge](https://github.com/swalladge)
* [@rvignesh89](https://github.com/rvignesh89)
* [@okolimar](https://github.com/okolimar)
* [@hansegucker](https://github.com/hansegucker)